/*
 * DVD Player plugin for VDR
 *
 * Copyright (C) 2001.2002 Andreas Schultz <aschultz@warp10.net>
 *
 * This code is distributed under the terms and conditions of the
 * GNU GENERAL PUBLIC LICENSE. See the file COPYING for details.
 *
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "i18n.h"

const char *ISO639code[] = {
  // Language ISO 639 codes for DVD
    "en",
    "de",
    "sl",
    "it",
    "nl",
    "pt",
    "fr",
    "no",
    "fi",
    "pl",
    "es",
    "el",
    "se",
    "ro",
    "hu",
    "ca",
    "ru",
    "hr",
    "et",
    "da",
#if VDRVERSNUM >= 10342
    "cs",
#endif
};

const tI18nPhrase DvdPhrases[] = {
    {
    "Plugin.DVD$DVD",                                       // English
        "DVD",                                              // Deutsch
        "DVD",                                              // Slovenski
        "DVD",                                              // Italiano
        "DVD",                                              // Nederlands
        "DVD",                                              // Portugus
        "DVD",                                              // Franais
        "DVD",                                              // Norsk
        "DVD",                                              // suomi
        "DVD",                                              // Polski
        "DVD",                                              // Espaol
        "DVD",                                              //  (Greek)
        "DVD",                                              // Svenska
        "DVD",                                              // Romaneste
        "DVD",                                              // Magyar
        "DVD",                                              // Catal
        " DVD",                                //  (Russian)
        "DVD",                                              // Hrvatski (Croatian)
        "DVD",                                              // Eesti
        "DVD",                                              // Dansk
#if VDRVERSNUM >= 10342
        "DVD",                                              // Czech
#endif
    },
    {
    "Plugin.DVD$turn VDR into an (almost) full featured DVD player",    // English
        "verwandelt VDR in einen (fast) vollstndigen DVD Spieler",     // Deutsch
        "",                                                             // Slovenski
        "",                                                             // Italiano
        "Verander VDR in een (bijna) complete DVD-speler",              // Nederlands
        "",                                                             // Portugus
        "",                                                             // Franais
        "",                                                             // Norsk
        "DVD-soitin",                                                   // suomi
        "Zmienia VDR w odtwarzacz DVD",                                 // Polski
        "Convierte VDR en un reproductor DVD (casi) completo",          // Espaol
        "",                                                             //  (Greek)
        "",                                                             // Svenska
        "",                                                             // Romaneste
        "",                                                             // Magyar
        "",                                                             // Catal
        " DVD",                                            //  (Russian)
        "",                                                             // Hrvatski (Croatian)
        "DVD-mngija",                                                  // Eesti
        "forvandler VDR til en (nsten) normal DVD afspiller",          // Dansk
#if VDRVERSNUM >= 10342
        "Pemn VDR v plnohodnotn DVD pehrva",                     // Czech
#endif
    },
    {
    "Setup.DVD$Preferred menu language",                    // English
        "Bevorzugte Spache fr Mens",                      // Deutsch
        "",                                                 // Slovenski
        "menu - linguaggio preferito",                      // Italiano
        "Taalkeuze voor menu",                              // Nederlands
        "",                                                 // Portugus
        "Langage prfr pour les menus",                   // Franais
        "",                                                 // Norsk
        "Haluttu valikkokieli",                             // suomi
        "Preferowany jzyk menu",                           // Polski
        "Idioma preferido para los mens",                  // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "  ",                         //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Eelistatud menkeel",                             // Eesti
        "Foretrukket sprog for menuer",                     // Dansk
#if VDRVERSNUM >= 10342
        "Preferovan jazyk menu",                           // Czech
#endif
    },
    {
    "Setup.DVD$Preferred audio language",                   // English
        "Bevorzugte Sprache fr Dialog",                    // Deutsch
        "",                                                 // Slovenski
        "audio - linguaggio preferito",                     // Italiano
        "Taalkeuze voor geluid",                            // Nederlands
        "",                                                 // Portugus
        "Langage prfr pour le son",                      // Franais
        "",                                                 // Norsk
        "Haluttu niraita",                                // suomi
        "Preferowany jzyk dwiku",                        // Polski
        "Idioma preferido para el sonido",                  // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "  ",                        //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Eelistatud audiokeel",                             // Eesti
        "Foretrukket sprog for lyd",                        // Dansk
#if VDRVERSNUM >= 10342
        "Preferovan jazyk zvuku",                          // Czech
#endif
    },
    {
    "Setup.DVD$Preferred subtitle language",                // English
        "Bevorzugte Spache fr Untertitel",                 // Deutsch
        "",                                                 // Slovenski
        "sottotitoli - linguaggio preferito",               // Italiano
        "Taalkeuze voor ondertitels",                       // Nederlands
        "",                                                 // Portugus
        "Langage prfr pour les sous-titres",             // Franais
        "",                                                 // Norsk
        "Haluttu tekstityskieli",                           // suomi
        "Preferowany jzyk napisw",                        // Polski
        "Idioma preferido para los subttulos",             // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "  ",                    //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Eelistatud subtiitritekeel",                       // Eesti
        "Foretrukket sprog for undertekster",               // Dansk
#if VDRVERSNUM >= 10342
        "Preferovan jazyk titulk",                        // Czech
#endif
    },
    {
    "Setup.DVD$Player region code",                         // English
        "Regionalkode fr DVD Spieler",                     // Deutsch
        "",                                                 // Slovenski
        "region code del DVD player",                       // Italiano
        "Regiocode van Speler",                             // Nederlands
        "",                                                 // Portugus
        "Code rgion du lecteur",                           // Franais
        "",                                                 // Norsk
        "Soittimen aluekoodi",                              // suomi
        "Kod regionu odtwarzacza",                          // Polski
        "Cdigo de zona del lector",                        // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        " ",                                         //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Mngija regioonikood",                             // Eesti
        "Afspillerens regions kode",                        // Dansk
#if VDRVERSNUM >= 10342
        "Regionln kd pehrvae",                        // Czech
#endif
    },
    {
    "Setup.DVD$Display subtitles",                          // English
        "Untertitel anzeigen",                              // Deutsch
        "",                                                 // Slovenski
        "Visualizza sottotitoli",                           // Italiano
        "Toon ondertitels",                                 // Nederlands
        "",                                                 // Portugus
        "Affiche les sous-titres",                          // Franais
        "",                                                 // Norsk
        "Nyt tekstitys",                                  // suomi
        "Wywietlaj napisy",                                // Polski
        "Mostrar subttulos",                               // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        " ",                              //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Subtiitrite kuvamine",                             // Eesti
        "Vis undertekster",                                 // Dansk
#if VDRVERSNUM >= 10342
        "Zobrazovat titulky",                               // Czech
#endif
    },
    {
     "Setup.DVD$Hide Mainmenu Entry",
        "Hauptmeneintrag verstecken",                      // Deutsch
        "",                                                 // Slovenski
        "Nascondi voce men",                               // Italiano
        "Verberg vermelding in het hoofdmenu",              // Nederlands
        "",                                                 // Portugus
        "",                                                 // Franais
        "",                                                 // Norsk
        "Piilota valinta pvalikosta",                     // suomi
        "Ukryj pozycj w gwnym menu",                     // Polski
        "Ocultar entrada en el men principal",             // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "    ",                    //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Peita peamen valikust",                          // Eesti
        "Skjul DVD i hovedmenuen",                          // Dansk
#if VDRVERSNUM >= 10342
        "Skrt poloku v hlavnm menu",                     // Czech
#endif
    },
    {
     "Setup.DVD$ReadAHead",
        "ReadAHead",                                        // Deutsch
        "ReadAHead",                                        // Slovenski
        "ReadAHead",                                        // Italiano
        "Vooruit lezen",                                    // Nederlands
        "ReadAHead",                                        // Portugus
        "ReadAHead",                                        // Franais
        "ReadAHead",                                        // Norsk
        "ReadAHead-toiminto",                               // suomi
        "ReadAHead",                                        // Polski
        "Lectura anticipada",                               // Espaol
        "ReadAHead",                                        //  (Greek)
        "ReadAHead",                                        // Svenska
        "ReadAHead",                                        // Romaneste
        "ReadAHead",                                        // Magyar
        "ReadAHead",                                        // Catal
        " ",                               //  (Russian)
        "ReadAHead",                                        // Hrvatski (Croatian)
        "ReadAHead",                                        // Eesti
        "Ls forud",                                        // Dansk
#if VDRVERSNUM >= 10342
        "Dopedn ten",                                   // Czech
#endif
    },
    {
     "Setup.DVD$Gain (analog)",
     "Verstrkung (analog)",                                // Deutsch
     "Gain (analog)",                                       // Slovenski
     "Gain (analog)",                                       // Italiano
     "Versterking (analoog)",                               // Nederlands
     "Gain (analog)",                                       // Portugus
     "Gain (analog)",                                       // Franais
     "Gain (analog)",                                       // Norsk
     "nen vahvistus (analoginen)",                        // suomi
     "Zysk (analogowo)",                                    // Polski
     "Ganancia (analgico)",                                // Espaol
     "Gain (analog)",                                       //  (Greek)
     "Gain (analog)",                                       // Svenska
     "Gain (analog)",                                       // Romaneste
     "Gain (analog)",                                       // Magyar
     "Gain (analog)",                                       // Catal
     " (.)",                                  //  (Russian)
     "Gain (analog)",                                       // Hrvatski (Croatian)
     "Helivimendamine (analoog)",                          // Eesti
     "Forstrkning (analog)",                               // Dansk
#if VDRVERSNUM >= 10342
     "Zeslen (analog)",                                   // Czech
#endif
    },
    {
    "Error.DVD$Error opening DVD!",                         // English
        "Fehler beim ffnen der DVD!",                      // Deutsch
        "",                                                 // Slovenski
        "",                                                 // Italiano
        "Fout bij het openen van de DVD!",                  // Nederlands
        "",                                                 // Portugus
        "",                                                 // Franais
        "",                                                 // Norsk
        "DVD:n avaaminen eponnistui!",                     // suomi
        "Bd otwierania DVD!",                             // Polski
        "Error abriendo el DVD!",                          // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "  DVD!",                             //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "DVD avamine ebannestus!",                         // Eesti
        "Fejl ved bning af DVD!",                          // Dansk
#if VDRVERSNUM >= 10342
        "Chyba pi otevrn DVD!",                         // Czech
#endif
    },
    {
    "Error.DVD$Error fetching data from DVD!",              // English
        "Fehler beim lesen von der DVD!",                   // Deutsch
        "",                                                 // Slovenski
        "",                                                 // Italiano
        "Error bij het verkrijgen van data van de DVD!",    // Nederlands
        "",                                                 // Portugus
        "",                                                 // Franais
        "",                                                 // Norsk
        "DVD:n lukeminen eponnistui",                      // suomi
        "Bd pobierania danych z DVD!",                    // Polski
        "Error obteniendo datos del DVD!",                 // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "  DVD!",                               //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Lugemine DVD-lt ebannestus!",                     // Eesti
        "Fejl ved hentning af data fra DVD!",               // Dansk
#if VDRVERSNUM >= 10342
        "Chyba pi natn dat z DVD!",                    // Czech
#endif
    },
    {
    "Error.DVD$Current subp stream not seen!",              // English
        "Der ausgewhlte Untertitel ist nicht vorhanden!",  // Deutsch
        "",                                                 // Slovenski
        "",                                                 // Italiano
        "De gekozen ondertiteling is niet beschikbaar!",    // Nederlands
        "",                                                 // Portugus
        "",                                                 // Franais
        "",                                                 // Norsk
        "Tekstitysraitaa ei havaita!",                      // suomi
        "Wybrane napisy nie istniej!",                     // Polski
        "Subttulos actuales no encontrados!",             // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "   !",          //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Subtiitriterada pole avastatud!",                  // Eesti
        "Valgte undertekst findes ikke!",                   // Dansk
#if VDRVERSNUM >= 10342
        "Vybran titulky nejsou k dispozici!",              // Czech
#endif
    },
    {
    "Error.DVD$Current audio track not seen!",              // English
        "Die ausgewhlte Audiospur ist nicht vorhanden!",   // Deutsch
        "",                                                 // Slovenski
        "",                                                 // Italiano
        "Het gekozen audiospoort is niet beschikbaar",      // Nederlands
        "",                                                 // Portugus
        "",                                                 // Franais
        "",                                                 // Norsk
        "niraitaa ei havaita!",                           // suomi
        "Wybrana cieka dwikowa nie istnieje!",          // Polski
        "Pista de audio actual no encontrada!",            // Espaol
        "",                                                 //  (Greek)
        "",                                                 // Svenska
        "",                                                 // Romaneste
        "",                                                 // Magyar
        "",                                                 // Catal
        "  !",                   //  (Russian)
        "",                                                 // Hrvatski (Croatian)
        "Audiorada pole avastatud!",                        // Eesti
        "Valgte lyd-spor findes ikke!",                     // Dansk
#if VDRVERSNUM >= 10342
        "Vybran zvukov stopa nen k dispozici!",          // Czech
#endif
    },
    { NULL }
};
